/*

	by Serge FANTINO - fantino@math.unice.fr
	
*/

#ifndef SPLITER_H
#define SPLITER_H

#include <View.h>
#include <Cursor.h>

#define K_SET_HORIZONTAL 'kSHZ'
#define K_SET_VERTICAL 'kSVT'
#define K_TOGGLE_ORIENTATION 'kTGL'

void draw_separator(BView *owner,orientation posture);

class KSeparator {
public:

	KSeparator(float width,orientation posture);
	
	const orientation	Posture();
	void  SetPosture(orientation);
	const float 		Width();
	
	void SetLimits(float min,float max);
	float BeforeHidingSize();
	
	virtual void SplitTo(BPoint left_top,float height,KSeparator *source=NULL);
	virtual void XSplitTo(BPoint left_top,float height,KSeparator *source=NULL);
	
protected:
	
	virtual BRect	frame()=0;
	virtual BView	*next_sibling()=0;
	virtual BView	*previous_sibling()=0;
	virtual void move_to(BPoint)=0;
	virtual void disable_updates(bool flag)=0;
	
	float	fMin,fMax,fBeforeHidingSize;
private:

	orientation		fPosture;
	float		fWidth;
	
	
};

class KSeparatorView : public BView, public KSeparator {
public:

	KSeparatorView(orientation posture,const char *name,float width=9);
	
	//orientation	Posture();
	//virtual void Draw(BRect update);
	
	virtual void SplitTo(BPoint left_top,KSeparator *source=NULL);
	
	virtual void GetPreferredSize(float *width,float *height);
	
protected:
	
	virtual BRect	frame();
	virtual BView	*next_sibling();
	virtual BView	*previous_sibling();
	virtual void move_to(BPoint);
	virtual void disable_updates(bool flag);
	
};

class KSplitView : public KSeparatorView {
public:

	KSplitView(orientation posture,const char *name);
	
	//void SetLimits(float min,float max);
	
	virtual void Draw(BRect update);
	
	virtual void AllAttached(void);
	void SetDefaultLimits();

	virtual void MouseDown(BPoint where);
	virtual void MouseUp(BPoint where);
	virtual void MouseMoved(BPoint point, uint32 transit, const BMessage *message);

	//void __SplitTo(BPoint left_top,BView *source=NULL);
private:

	bool	fTracking;
	BPoint	fOffset;
	//BPoint	fMin,fMax;
	//float	fMin,fMax,fBeforeHiddingSize;
};

// -----------------------------------------------
#ifdef COMPATIBLE_SUCKS
struct simple_pack_info;

class KSplitPane : public BView {
public:
	KSplitPane(BRect rect,const char *name,orientation posture,uint32 resizingMode=0,uint32 flags=0);
	~KSplitPane();
	
	orientation Posture();
	void SetPosture(orientation posture);
	
	virtual void AttachedToWindow(void) ;
	
	void AddChild(BView *view);
	status_t RemoveChild(BView *view);
	status_t HideChild(BView *view);
	int32 IndexOf(BView *view);
	
	virtual void MessageReceived(BMessage *message);
	
	void SetFollowAllView(BView *view);
	void ResetFollowAll();
	
protected:
	friend KSplit;

	void really_add_child(simple_pack_info *info,simple_pack_info *previous);
	
	void pack_everything();
	
	void resize_by(float x,float y);

private:
	typedef BView inherited;	
	
	orientation fPosture;
	
	BList *fQueue;
	BList *fInfo;
	bool fFirstTime;
};
#endif
#endif